@@ -1,7 +1,7 @@
 
 from generallibrary import EnvVar
 
-PACKAGER_GITHUB_API = EnvVar("PACKAGER_GITHUB_API", "secrets.PACKAGER_GITHUB_API")
+GH_TOKEN = EnvVar("GH_TOKEN", "secrets.PACKAGER_GITHUB_API")
 TWINE_USERNAME = EnvVar("TWINE_USERNAME", "secrets.TWINE_USERNAME")
 TWINE_PASSWORD = EnvVar("TWINE_PASSWORD", "secrets.TWINE_PASSWORD")
 
